@@ -9,7 +9,7 @@ class tests(unittest.TestCase):
 
     def test_trigger_pdb(self):
         #this is the way I do it now
-        from src import BoolSeries, IntSeries, FloatSeries, StrSeries, TDataFrame
+        from jackals import BoolSeries, IntSeries, FloatSeries, StrSeries, TDataFrame
         
         price = FloatSeries(elements=[7.0, 3.5, 8.0, 6.0])
         sales = IntSeries(elements=[5, 3, 1, 10])
